@@ -1,4 +1,4 @@
-# Copyright (c) 2011-2021, wradlib developers.
+# Copyright (c) 2011-2023, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 import datetime
@@ -8,7 +8,6 @@ import os
 import subprocess
 import sys
 import tempfile
-import zlib
 from dataclasses import dataclass
 
 import deprecation
@@ -31,7 +30,6 @@ from . import (
     requires_secrets,
     requires_xarray_backend_api,
     requires_xmltodict,
-    xmltodict,
 )
 
 
@@ -144,7 +142,7 @@ class TestMisc:
         name = tmp.name
         tmp.close()
         io.misc.write_polygon_to_text(name, polygons)
-        assert open(name, "r").readlines() == res
+        assert open(name).readlines() == res
 
     def test_pickle(self):
         arr = np.zeros((124, 248), dtype=np.int16)
@@ -1142,10 +1140,10 @@ class TestRadolan:
     def test_open_radolan_mfdataset(self):
         filename = "radolan/misc/raa01-rw_10000-1408030950-dwd---bin.gz"
         rw_file = util.get_wradlib_data_file(filename)
-
         data = io.radolan.open_radolan_mfdataset(rw_file)
         assert data.RW.shape == (900, 900)
-
+        filename2 = "radolan/misc/raa01-rw_10000-1408102050-dwd---bin.gz"
+        util.get_wradlib_data_file(filename2)
         data = io.radolan.open_radolan_mfdataset(
             rw_file[:-23] + "*.gz", concat_dim="time"
         )
@@ -1178,127 +1176,6 @@ class TestRainbow:
             rb_dict = io.rainbow.read_rainbow(f)
         assert rb_dict["volume"]["@datetime"] == "2013-07-03T08:33:55"
 
-    def test_find_key(self):
-        indict = {
-            "A": {
-                "AA": {"AAA": 0, "X": 1},
-                "AB": {"ABA": 2, "X": 3},
-                "AC": {"ACA": 4, "X": 5},
-                "AD": [{"ADA": 4, "X": 2}],
-            }
-        }
-        outdict = [
-            {"X": 1, "AAA": 0},
-            {"ABA": 2, "X": 3},
-            {"X": 5, "ACA": 4},
-            {"ADA": 4, "X": 2},
-        ]
-
-        assert list(io.rainbow.find_key("X", indict)) == outdict
-        assert list(io.rainbow.find_key("Y", indict)) == []
-
-    def test_decompress(self):
-        dstring = b"very special compressed string"
-        cstring = zlib.compress(dstring)
-        assert io.rainbow.decompress(cstring) == dstring
-
-    def test_get_rb_data_layout(self):
-        assert io.rainbow.get_rb_data_layout(8) == (1, ">u1")
-        assert io.rainbow.get_rb_data_layout(16) == (2, ">u2")
-        assert io.rainbow.get_rb_data_layout(32) == (4, ">u4")
-        with pytest.raises(ValueError):
-            io.rainbow.get_rb_data_layout(128)
-
-    def test_get_rb_data_layout_big(self):
-        from unittest.mock import patch
-
-        with patch("sys.byteorder", "big"):
-            assert io.rainbow.get_rb_data_layout(8) == (1, "<u1")
-            assert io.rainbow.get_rb_data_layout(16) == (2, "<u2")
-            assert io.rainbow.get_rb_data_layout(32) == (4, "<u4")
-
-    @requires_xmltodict
-    def test_get_rb_data_attribute(self):
-        data = xmltodict.parse(
-            (
-                '<slicedata time="13:30:05" date="2013-04-26">'
-                '#<rayinfo refid="startangle" blobid="0" '
-                'rays="361" depth="16"/> '
-                '#<rawdata blobid="1" rays="361" type="dBuZ" '
-                'bins="400" min="-31.5" max="95.5" '
-                'depth="8"/> #</slicedata>'
-            )
-        )
-        data = list(io.rainbow.find_key("@blobid", data))
-        assert io.rainbow.get_rb_data_attribute(data[0], "blobid") == 0
-        assert io.rainbow.get_rb_data_attribute(data[1], "blobid") == 1
-        assert io.rainbow.get_rb_data_attribute(data[0], "rays") == 361
-        assert io.rainbow.get_rb_data_attribute(data[1], "rays") == 361
-        assert io.rainbow.get_rb_data_attribute(data[1], "bins") == 400
-        with pytest.raises(KeyError):
-            io.rainbow.get_rb_data_attribute(data[0], "Nonsense")
-        assert io.rainbow.get_rb_data_attribute(data[0], "depth") == 16
-
-    @requires_xmltodict
-    def test_get_rb_blob_attribute(self):
-        xmldict = xmltodict.parse(
-            '<BLOB blobid="0" size="737" compression="qt"></BLOB>'
-        )
-        assert io.rainbow.get_rb_blob_attribute(xmldict, "compression") == "qt"
-        assert io.rainbow.get_rb_blob_attribute(xmldict, "size") == "737"
-        assert io.rainbow.get_rb_blob_attribute(xmldict, "blobid") == "0"
-        with pytest.raises(KeyError):
-            io.rainbow.get_rb_blob_attribute(xmldict, "Nonsense")
-
-    @requires_xmltodict
-    def test_get_rb_data_shape(self):
-        data = xmltodict.parse(
-            (
-                '<slicedata time="13:30:05" date="2013-04-26">'
-                '#<rayinfo refid="startangle" blobid="0" '
-                'rays="361" depth="16"/> #<rawdata blobid="1" '
-                'rays="361" type="dBuZ" bins="400" '
-                'min="-31.5" max="95.5" depth="8"/> #<flagmap '
-                'blobid="2" rows="800" type="dBuZ" '
-                'columns="400" min="-31.5" max="95.5" '
-                'depth="6"/> #<defect blobid="3" type="dBuZ" '
-                'columns="400" min="-31.5" max="95.5" '
-                'depth="6"/> #<rawdata2 '
-                'blobid="4" rows="800" type="dBuZ" '
-                'columns="400" min="-31.5" max="95.5" '
-                'depth="8"/> #</slicedata>'
-            )
-        )
-        data = list(io.rainbow.find_key("@blobid", data))
-        assert io.rainbow.get_rb_data_shape(data[0]) == 361
-        assert io.rainbow.get_rb_data_shape(data[1]) == (361, 400)
-        assert io.rainbow.get_rb_data_shape(data[2]) == (800, 400, 6)
-        assert io.rainbow.get_rb_data_shape(data[4]) == (800, 400)
-        with pytest.raises(KeyError):
-            io.rainbow.get_rb_data_shape(data[3])
-
-    def test_map_rb_data(self):
-        indata = b"0123456789"
-        outdata8 = np.array([48, 49, 50, 51, 52, 53, 54, 55, 56, 57], dtype=np.uint8)
-        outdata16 = np.array([12337, 12851, 13365, 13879, 14393], dtype=np.uint16)
-        outdata32 = np.array([808530483, 875902519], dtype=np.uint32)
-        np.testing.assert_allclose(io.rainbow.map_rb_data(indata, 8), outdata8)
-        np.testing.assert_allclose(io.rainbow.map_rb_data(indata, 16), outdata16)
-        np.testing.assert_allclose(io.rainbow.map_rb_data(indata, 32), outdata32)
-        flagdata = b"1"
-        np.testing.assert_allclose(
-            io.rainbow.map_rb_data(flagdata, 1, 8), [0, 0, 1, 1, 0, 0, 0, 1]
-        )
-        # added test for truncation
-        np.testing.assert_allclose(
-            io.rainbow.map_rb_data(flagdata, 1, 6), [0, 0, 1, 1, 0, 0]
-        )
-
-    def test_get_rb_blob_data(self):
-        datastring = b'<BLOB blobid="0" size="737" compression="qt"></BLOB>'
-        with pytest.raises(EOFError):
-            io.rainbow.get_rb_blob_data(datastring, 1)
-
     @requires_data
     @requires_xmltodict
     def test_get_rb_blob_from_file(self, file_or_filelike):
@@ -1326,68 +1203,6 @@ class TestRainbow:
             with pytest.raises(IOError):
                 io.rainbow.get_rb_file_as_string("rb_fh")
 
-    def test_get_rb_header(self):
-        rb_header = (
-            b'<volume version="5.34.16" '
-            b'datetime="2013-07-03T08:33:55"'
-            b' type="azi" owner="RainAnalyzer"> '
-            b'<scan name="analyzer.azi" time="08:34:00" '
-            b'date="2013-07-03">'
-        )
-
-        buf = sio.BytesIO(rb_header)
-        with pytest.raises(IOError):
-            io.rainbow.get_rb_header(buf)
-
-    @requires_data
-    @requires_xmltodict
-    def test_get_rb_header_from_file(self):
-        filename = "rainbow/2013070308340000dBuZ.azi"
-        rb_file = util.get_wradlib_data_file(filename)
-        with open(rb_file, "rb") as rb_fh:
-            rb_header = io.rainbow.get_rb_header(rb_fh)
-            assert rb_header["volume"]["@version"] == "5.34.16"
-
-    @requires_data
-    @requires_xmltodict
-    def test_rainbow_file_meta(self):
-        filename = "rainbow/2013070308340000dBuZ.azi"
-        rb_file = util.get_wradlib_data_file(filename)
-        with io.rainbow.RainbowFile(rb_file, loaddata=False) as rbdict:
-            assert rbdict.version == "5.34.16"
-            assert rbdict.header
-            assert rbdict.site_coords == (6.33097, 50.5049, 0.0)
-            assert rbdict.first_dimension == "azimuth"
-            assert rbdict.history
-            assert rbdict.pargroup
-            assert rbdict.sensorinfo == dict(
-                [
-                    ("@type", "rainscanner"),
-                    ("@id", "WUE"),
-                    ("@name", "Wuestebach"),
-                    ("lon", "6.330970"),
-                    ("lat", "50.504900"),
-                    ("alt", "0.000000"),
-                    ("wavelen", "0.05"),
-                    ("beamwidth", "1"),
-                ]
-            )
-            assert rbdict.datetime == datetime.datetime(2013, 7, 3, 8, 33, 55)
-            assert rbdict.type == "azi"
-
-    @requires_data
-    @requires_xmltodict
-    def test_rainbow_file_data(self):
-        filename = "rainbow/2013070308340000dBuZ.azi"
-        rb_file = util.get_wradlib_data_file(filename)
-        with io.rainbow.RainbowFile(rb_file, loaddata=True) as rbdict:
-            sdata = rbdict.slices[0]["slicedata"]
-            np.testing.assert_equal(
-                sdata["rayinfo"]["data"][0], np.array([120.9979248046875])
-            )
-            np.testing.assert_equal(sdata["rawdata"]["data"][0, 0], np.array([167]))
-            assert sdata["rawdata"]["data"].shape == (360, 500)
-
 
 class TestRaster:
     @requires_gdal
@@ -1436,6 +1251,8 @@ class TestVector:
     @requires_data
     @requires_gdal
     def test_open_vector(self):
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.dbf")
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.shx")
         filename = "shapefiles/agger/agger_merge.shp"
         geofile = util.get_wradlib_data_file(filename)
         io.gdal.open_vector(geofile)
@@ -1482,6 +1299,8 @@ class TestVectorSource:
     @requires_data
     @requires_gdal
     def test__check_src(self):
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.dbf")
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.shx")
         from osgeo import osr
 
         proj_gk2 = osr.SpatialReference()
@@ -1491,6 +1310,8 @@ class TestVectorSource:
 
     @requires_gdal
     def test_error(self):
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.dbf")
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.shx")
         with pytest.raises(ValueError):
             filename = util.get_wradlib_data_file("shapefiles/agger/agger_merge.shp")
             io.VectorSource(filename)
@@ -1554,11 +1375,13 @@ class TestVectorSource:
     @requires_data
     @requires_gdal
     def test_get_geom_properties(self):
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.dbf")
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.shx")
         from osgeo import osr
 
         proj = osr.SpatialReference()
         proj.ImportFromEPSG(31466)
-        filename = util.get_wradlib_data_file("shapefiles/agger/" "agger_merge.shp")
+        filename = util.get_wradlib_data_file("shapefiles/agger/agger_merge.shp")
         test = io.VectorSource(filename, proj)
         np.testing.assert_array_equal(
             [[76722499.98474795]], test.get_geom_properties(["Area"], filt=("FID", 1))
@@ -1569,14 +1392,24 @@ class TestVectorSource:
         ds = io.VectorSource(data_source.data)
         ds.dump_vector(tempfile.NamedTemporaryFile(mode="w+b").name)
 
+    @requires_gdal
+    def test_clean_up_temporary_files(self, data_source):
+        ds = io.VectorSource(data_source.data)
+        tempdir = ds.ds.GetDescription()
+        assert os.path.exists(tempdir)
+        ds.close()
+        assert not os.path.exists(tempdir)
+
     @requires_data
     @requires_gdal
     def test_dump_raster(self):
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.dbf")
+        util.get_wradlib_data_file("shapefiles/agger/agger_merge.shx")
         from osgeo import osr
 
         proj = osr.SpatialReference()
         proj.ImportFromEPSG(31466)
-        filename = util.get_wradlib_data_file("shapefiles/agger/" "agger_merge.shp")
+        filename = util.get_wradlib_data_file("shapefiles/agger/agger_merge.shp")
         test = io.VectorSource(filename, srs=proj)
         test.dump_raster(
             tempfile.NamedTemporaryFile(mode="w+b").name,
@@ -1592,18 +1425,6 @@ class TestVectorSource:
 
 
 class TestIris:
-    @requires_data
-    def test_open_iris(self, file_or_filelike):
-        filename = "sigmet/cor-main131125105503.RAW2049"
-        with get_wradlib_data_file(filename, file_or_filelike) as sigmetfile:
-            data = io.iris.IrisRawFile(sigmetfile, loaddata=False)
-        assert isinstance(data.rh, io.iris.IrisRecord)
-        assert isinstance(data.fh, (np.memmap, np.ndarray))
-        with get_wradlib_data_file(filename, file_or_filelike) as sigmetfile:
-            data = io.iris.IrisRawFile(sigmetfile, loaddata=True)
-        assert data._record_number == 511
-        assert data.filepos == 3139584
-
     @requires_data
     def test_open_iris_cartesian_product(self):
         filename = "sigmet/SUR160703220000.MAX71NP.gz"
@@ -1611,7 +1432,7 @@ class TestIris:
             data = io.iris.IrisCartesianProductFile(
                 sigmetfile, loaddata=True, origin="lower"
             )
-        assert isinstance(data.rh, io.iris.IrisRecord)
+        assert isinstance(data.rh, io.iris.xiris.IrisRecord)
         assert isinstance(data.fh, (np.memmap, np.ndarray))
 
     @requires_data
@@ -1673,169 +1494,6 @@ class TestIris:
         assert not set(data_types) - set(data["data"][1]["sweep_data"])
         assert set(data["data"]) == set(selected_data)
 
-    @requires_data
-    def test_IrisRecord(self, file_or_filelike):
-        filename = "sigmet/cor-main131125105503.RAW2049"
-        with get_wradlib_data_file(filename, file_or_filelike) as sigmetfile:
-            data = io.iris.IrisRecordFile(sigmetfile, loaddata=False)
-        # reset record after init
-        data.init_record(1)
-        assert isinstance(data.rh, io.iris.IrisRecord)
-        assert data.rh.pos == 0
-        assert data.rh.recpos == 0
-        assert data.rh.recnum == 1
-        rlist = [23, 0, 4, 0, 20, 19, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0]
-        np.testing.assert_array_equal(data.rh.read(10, 2), rlist)
-        assert data.rh.pos == 20
-        assert data.rh.recpos == 10
-        data.rh.pos -= 20
-        np.testing.assert_array_equal(data.rh.read(20, 1), rlist)
-        data.rh.recpos -= 10
-        np.testing.assert_array_equal(data.rh.read(5, 4), rlist)
-
-    def test_decode_bin_angle(self):
-        assert io.iris.decode_bin_angle(20000, 2) == 109.86328125
-        assert io.iris.decode_bin_angle(2000000000, 4) == 167.63806343078613
-
-    def decode_array(self):
-        data = np.arange(0, 11)
-        np.testing.assert_array_equal(
-            io.iris.decode_array(data),
-            [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0],
-        )
-        np.testing.assert_array_equal(
-            io.iris.decode_array(data, offset=1.0),
-            [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0],
-        )
-        np.testing.assert_array_equal(
-            io.iris.decode_array(data, scale=0.5),
-            [0, 2.0, 4.0, 6.0, 8.0, 10.0, 12.0, 14.0, 16.0, 18.0, 20.0],
-        )
-        np.testing.assert_array_equal(
-            io.iris.decode_array(data, offset=1.0, scale=0.5),
-            [2.0, 4.0, 6.0, 8.0, 10.0, 12.0, 14.0, 16.0, 18.0, 20.0, 22.0],
-        )
-        np.testing.assert_array_equal(
-            io.iris.decode_array(data, offset=1.0, scale=0.5, offset2=-2.0),
-            [0, 2.0, 4.0, 6.0, 8.0, 10.0, 12.0, 14.0, 16.0, 18.0, 20.0],
-        )
-        data = np.array(
-            [0, 1, 255, 1000, 9096, 22634, 34922, 50000, 65534], dtype=np.uint16
-        )
-        np.testing.assert_array_equal(
-            io.iris.decode_array(data, scale=1000, tofloat=True),
-            [0.0, 0.001, 0.255, 1.0, 10.0, 100.0, 800.0, 10125.312, 134184.96],
-        )
-
-    def test_decode_kdp(self):
-        np.testing.assert_array_almost_equal(
-            io.iris.decode_kdp(np.arange(-5, 5, dtype="int8"), wavelength=10.0),
-            [
-                12.243229,
-                12.880858,
-                13.551695,
-                14.257469,
-                15.0,
-                -0.0,
-                -15.0,
-                -14.257469,
-                -13.551695,
-                -12.880858,
-            ],
-        )
-
-    def test_decode_phidp(self):
-        np.testing.assert_array_almost_equal(
-            io.iris.decode_phidp(
-                np.arange(0, 10, dtype="uint8"), scale=254.0, offset=-1
-            ),
-            [
-                -0.70866142,
-                0.0,
-                0.70866142,
-                1.41732283,
-                2.12598425,
-                2.83464567,
-                3.54330709,
-                4.2519685,
-                4.96062992,
-                5.66929134,
-            ],
-        )
-
-    def test_decode_phidp2(self):
-        np.testing.assert_array_almost_equal(
-            io.iris.decode_phidp2(
-                np.arange(0, 10, dtype="uint16"), scale=65534.0, offset=-1
-            ),
-            [
-                -0.00549333,
-                0.0,
-                0.00549333,
-                0.01098666,
-                0.01648,
-                0.02197333,
-                0.02746666,
-                0.03295999,
-                0.03845332,
-                0.04394665,
-            ],
-        )
-
-    def test_decode_sqi(self):
-        np.testing.assert_array_almost_equal(
-            io.iris.decode_sqi(np.arange(0, 10, dtype="uint8"), scale=253.0, offset=-1),
-            [
-                np.nan,
-                0.0,
-                0.06286946,
-                0.08891084,
-                0.1088931,
-                0.12573892,
-                0.14058039,
-                0.1539981,
-                0.16633696,
-                0.17782169,
-            ],
-        )
-
-    def test_decode_rainrate2(self):
-        vals = np.array(
-            [0, 1, 2, 255, 1000, 9096, 22634, 34922, 50000, 65534, 65535],
-            dtype="uint16",
-        )
-        prod = io.iris.SIGMET_DATA_TYPES[13]
-        np.testing.assert_array_almost_equal(
-            io.iris.decode_array(vals.copy(), **prod["fkw"]),
-            [
-                -1.00000000e-04,
-                0.00000000e00,
-                1.00000000e-04,
-                2.54000000e-02,
-                9.99000000e-02,
-                9.99900000e-01,
-                9.99990000e00,
-                7.99999000e01,
-                1.01253110e03,
-                1.34184959e04,
-                1.34201343e04,
-            ],
-        )
-
-    def test_decode_time(self):
-        timestring = b"\xd1\x9a\x00\x000\t\xdd\x07\x0b\x00\x19\x00"
-        assert (
-            io.iris.decode_time(timestring).isoformat()
-            == "2013-11-25T11:00:33.304000+00:00"
-        )
-
-    def test_decode_string(self):
-        assert io.iris.decode_string(b"EEST\x00\x00\x00\x00") == "EEST"
-
-    def test__get_fmt_string(self):
-        fmt = "<12sHHi12s12s12s6s12s12sHiiiiiiiiii2sH12sHB1shhiihh80s16s12s48s"
-        assert io.iris._get_fmt_string(io.iris.PRODUCT_CONFIGURATION) == fmt
-
 
 class TestNetcdf:
     @requires_data
@@ -1891,253 +1549,6 @@ class TestXarray:
         with pytest.warns(DeprecationWarning):
             io.xarray.create_xarray_dataarray(img, r, az, th, proj=proj)
 
-    @requires_data
-    @requires_netcdf
-    def test_iter(self):
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile)
-        assert len(cf) == cf.sweep
-        assert len(cf) == 9
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    def test_del(self):
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile)
-        for k in list(cf):
-            del cf[k]
-        assert cf == {}
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    def test_read_cfradial(self):
-        sweep_names = [
-            "sweep_1",
-            "sweep_2",
-            "sweep_3",
-            "sweep_4",
-            "sweep_5",
-            "sweep_6",
-            "sweep_7",
-            "sweep_8",
-            "sweep_9",
-        ]
-        fixed_angles = np.array(
-            [0.4999, 1.0986, 1.8018, 2.5983, 3.598, 4.7021, 6.4984, 9.1022, 12.7991]
-        )
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile)
-        np.testing.assert_array_almost_equal(
-            cf.root.sweep_fixed_angle.values, fixed_angles
-        )
-        cfnames, cfangles = zip(*cf.sweeps)
-        assert sweep_names == list(cfnames)
-        np.testing.assert_array_almost_equal(fixed_angles, np.array(cfangles))
-        assert cf.sweep == 9
-        assert cf.location == (120.43350219726562, 22.52669906616211, 45.00000178813934)
-        assert cf.version == "1.2"
-        assert cf.Conventions == (
-            "CF/Radial instrument_parameters "
-            "radar_parameters radar_calibration "
-            "geometry_correction"
-        )
-
-        assert repr(cf) == repr(cf._sweeps)
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    def test_read_odim(self):
-        fixed_angles = np.array([0.3, 0.9, 1.8, 3.3, 6.0])
-        filename = "hdf5/20130429043000.rad.bewid.pvol.dbzh.scan1.hdf"
-        h5file = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.OdimH5(h5file)
-        np.testing.assert_array_almost_equal(
-            cf.root.sweep_fixed_angle.values, fixed_angles
-        )
-        filename = "hdf5/knmi_polar_volume.h5"
-        h5file = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.OdimH5(h5file)
-        with pytest.raises(AttributeError):
-            cf = io.xarray_depr.OdimH5(h5file, flavour="None")
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    @requires_h5py
-    def test_read_gamic(self):
-        time_cov = ("2014-08-10T18:23:35Z", "2014-08-10T18:24:05Z")
-        filename = "hdf5/2014-08-10--182000.ppi.mvol"
-        h5file = util.get_wradlib_data_file(filename)
-        with pytest.raises(AttributeError):
-            io.xarray_depr.OdimH5(h5file)
-        cf = io.xarray_depr.OdimH5(h5file, flavour="GAMIC")
-        assert str(cf.root.time_coverage_start.values) == time_cov[0]
-        assert str(cf.root.time_coverage_end.values) == time_cov[1]
-
-        filename = "hdf5/2014-06-09--185000.rhi.mvol"
-        h5file = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.OdimH5(h5file, flavour="GAMIC")
-        cf = io.xarray_depr.OdimH5(h5file, flavour="GAMIC", strict=False)
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    @requires_h5py
-    def test_odim_roundtrip(self):
-        filename = "hdf5/20130429043000.rad.bewid.pvol.dbzh.scan1.hdf"
-        odimfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.OdimH5(odimfile)
-        tmp = tempfile.NamedTemporaryFile(mode="w+b").name
-        cf.to_odim(tmp)
-        cf2 = io.xarray_depr.OdimH5(tmp)
-        xr.testing.assert_equal(cf.root, cf2.root)
-        for i in range(1, 6):
-            key = f"sweep_{i}"
-            xr.testing.assert_equal(cf[key], cf2[key])
-        # test write after del, file lockage
-        del cf2
-        # this currently breaks on CI, maybe the above `del` does not work correctly
-        # cf.to_odim(tmp)
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    def test_cfradial_roundtrip(self):
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile)
-        tmp = tempfile.NamedTemporaryFile(mode="w+b").name
-        cf.to_cfradial2(tmp)
-        cf2 = io.xarray_depr.CfRadial(tmp)
-        xr.testing.assert_equal(cf.root, cf2.root)
-        for i in range(1, 10):
-            key = f"sweep_{i}"
-            xr.testing.assert_equal(cf[key], cf2[key])
-        # test write after del, file lockage
-        del cf2
-        cf.to_cfradial2(tmp)
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    @requires_h5py
-    def test_cfradial_odim_roundtrip(self):
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile)
-        tmp = tempfile.NamedTemporaryFile(mode="w+b").name
-        cf.to_odim(tmp)
-        cf2 = io.xarray_depr.OdimH5(tmp)
-        xr.testing.assert_allclose(
-            cf.root.sweep_fixed_angle, cf2.root.sweep_fixed_angle
-        )
-        xr.testing.assert_allclose(
-            cf.root.time_coverage_start, cf2.root.time_coverage_start
-        )
-        drop = ["longitude", "latitude", "altitude", "sweep_mode"]
-        xr.testing.assert_allclose(
-            cf["sweep_1"].drop_vars(drop).sweep_number,
-            cf2["sweep_1"].drop_vars(drop).sweep_number,
-        )
-
-        tmp1 = tempfile.NamedTemporaryFile(mode="w+b").name
-        cf2.to_cfradial2(tmp1)
-        cf3 = io.xarray_depr.CfRadial(tmp1)
-        xr.testing.assert_allclose(
-            cf.root.time_coverage_start, cf3.root.time_coverage_start
-        )
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    @requires_gdal
-    def test_georeference(self):
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile, georef=True)
-        tmp = tempfile.NamedTemporaryFile(mode="w+b").name
-        cf.to_cfradial2(tmp)
-        cf2 = io.xarray_depr.CfRadial(tmp, georef=True)
-        swp1 = cf["sweep_1"].copy()
-        cf["sweep_1"] = cf["sweep_1"].drop_vars(["x", "y", "z", "gr", "rays", "bins"])
-        cf.georeference()
-        xr.testing.assert_equal(swp1, cf["sweep_1"])
-        xr.testing.assert_equal(swp1, cf2["sweep_1"])
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    def test_root_key_warnings(self):
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile)
-        with pytest.warns(DeprecationWarning):
-            cf["root"]
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    @requires_h5py
-    def test_to_odim_warning(self):
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile)
-        cf.root = None
-        with pytest.warns(UserWarning):
-            cf.to_odim("test.h5")
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    def test_to_cfradial2_warning(self):
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile)
-        cf.root = None
-        with pytest.warns(UserWarning):
-            cf.to_cfradial2("test.nc")
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    def test_setitem_warning(self):
-        filename = "netcdf/cfrad.20080604_002217_000_SPOL_v36_SUR.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        cf = io.xarray_depr.CfRadial(ncfile)
-        with pytest.warns(UserWarning):
-            cf["test"] = None
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    def test_odim_errors(self):
-        filename = "netcdf/edge_netcdf.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        with pytest.raises(TypeError):
-            io.xarray_depr.OdimH5(ncfile)
-
-        filename = "netcdf/example_cfradial_ppi.nc"
-        ncfile = util.get_wradlib_data_file(filename)
-        with pytest.raises(AttributeError):
-            io.xarray_depr.OdimH5(ncfile)
-
-    @deprecation.fail_if_not_removed
-    @requires_data
-    @requires_netcdf
-    def test_netcdf4_errors(self):
-        filename = "hdf5/2014-08-10--182000.ppi.mvol"
-        h5file = util.get_wradlib_data_file(filename)
-        with pytest.raises(AttributeError):
-            io.xarray_depr.CfRadial(h5file, flavour="Cf/Radial3")
-        with pytest.raises(AttributeError):
-            io.xarray_depr.CfRadial(h5file)
-
 
 class TestDem:
     def test_get_srtm_tile_names(self):
@@ -2189,6 +1600,11 @@ class TestDem:
         targets = ["N38W029", "N38W028", "N39W029", "N39W028"]
         targets = [f"{f}.SRTMGL3.hgt.zip" for f in targets]
 
+        # retrieve need files for offline test
+        util.get_wradlib_data_path()
+        for f in targets:
+            util.get_wradlib_data_file("geo/" + f)
+
         extent = [-28.5, -27.5, 38.5, 39.5]
         datasets = io.dem.get_srtm(extent, merge=False)
         filelist = [os.path.basename(d.GetFileList()[0]) for d in datasets]
@@ -2207,77 +1623,3 @@ class TestDem:
         ulcy = 40 + resolution / 2
         geo_ref = [ulcx, resolution, 0, ulcy, 0, -resolution]
         np.testing.assert_array_almost_equal(geo, geo_ref)
-
-
-class TestFuruno:
-    @requires_data
-    def test_open_scn(self, file_or_filelike):
-        filename = "furuno/0080_20210730_160000_01_02.scn.gz"
-        with get_wradlib_data_file(filename, file_or_filelike) as furunofile:
-            data = io.furuno.FurunoFile(furunofile, loaddata=False, obsmode=1)
-        assert isinstance(data, io.furuno.FurunoFile)
-        assert isinstance(data.fh, (np.memmap, np.ndarray))
-        with get_wradlib_data_file(filename, file_or_filelike) as furunofile:
-            data = io.furuno.FurunoFile(furunofile, loaddata=True, obsmode=1)
-        assert len(data.data) == 11
-        assert data.filename == furunofile
-        assert data.version == 3
-        assert data.a1gate == 796
-        assert data.angle_resolution == 0.26
-        assert data.first_dimension == "azimuth"
-        assert data.fixed_angle == 7.8
-        assert data.site_coords == (15.44729, 47.07734000000001, 407.9)
-        assert data.header["scan_start_time"] == datetime.datetime(2021, 7, 30, 16, 0)
-        assert list(data.data.keys()) == [
-            "RATE",
-            "DBZH",
-            "VRADH",
-            "ZDR",
-            "KDP",
-            "PHIDP",
-            "RHOHV",
-            "WRADH",
-            "QUAL",
-            "azimuth",
-            "elevation",
-        ]
-
-    def test_open_scn_filelike(self):
-        filename = "furuno/0080_20210730_160000_01_02.scn.gz"
-        with pytest.raises(
-            ValueError, match="Furuno `observation mode` can't be extracted"
-        ):
-            with get_wradlib_data_file(filename, "filelike") as furunofile:
-                data = io.furuno.FurunoFile(furunofile, loaddata=False)
-                print(data.first_dimension)
-
-    def test_open_scnx(self, file_or_filelike):
-        filename = "furuno/2006_20220324_000000_000.scnx.gz"
-        with get_wradlib_data_file(filename, file_or_filelike) as furunofile:
-            data = io.furuno.FurunoFile(furunofile, loaddata=False)
-        assert isinstance(data, io.furuno.FurunoFile)
-        assert isinstance(data.fh, (np.memmap, np.ndarray))
-        with get_wradlib_data_file(filename, file_or_filelike) as furunofile:
-            data = io.furuno.FurunoFile(furunofile, loaddata=True)
-        assert data.filename == furunofile
-        assert data.version == 10
-        assert data.a1gate == 292
-        assert data.angle_resolution == 0.5
-        assert data.first_dimension == "azimuth"
-        assert data.fixed_angle == 0.5
-        assert data.site_coords == (13.243970000000001, 53.55478, 38.0)
-        assert data.header["scan_start_time"] == datetime.datetime(2022, 3, 24, 0, 0, 1)
-        assert len(data.data) == 11
-        assert list(data.data.keys()) == [
-            "RATE",
-            "DBZH",
-            "VRADH",
-            "ZDR",
-            "KDP",
-            "PHIDP",
-            "RHOHV",
-            "WRADH",
-            "QUAL",
-            "azimuth",
-            "elevation",
-        ]
