@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
-# Copyright (c) 2011-2020, wradlib developers.
+# Copyright (c) 2011-2021, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 import warnings
@@ -10,6 +10,8 @@ import pytest
 
 from wradlib import georef, ipol
 
+from . import requires_gdal
+
 
 class TestInterpolation:
     # Kriging Variables
@@ -98,7 +100,7 @@ class TestInterpolation:
             ipol.cov_cau([0.0, 5.0, 10.0]), np.array([1.0, 0.16666667, 0.09090909])
         )
         assert np.allclose(
-            ipol.cov_cau([0.0, 5.0, 10.0], sill=2.0, rng=10.0,),
+            ipol.cov_cau([0.0, 5.0, 10.0], sill=2.0, rng=10.0),
             np.array([2.0, 1.33333333, 1.0]),
         )
         assert np.allclose(
@@ -381,6 +383,7 @@ class TestRectGridInterpolation:
         np.testing.assert_allclose(res0, res1)
         np.testing.assert_allclose(res0a, res1)
 
+    @requires_gdal
     def test_QuadriArea(self):
         grid2 = self.grid2 + (-0.01, 0.01)
         ip = ipol.QuadriArea(grid2, self.grid)
