@@ -26,6 +26,8 @@ __all__ = [
     "derivate",
     "despeckle",
     "import_optional",
+    "vertical_interpolate_volume",
+    "cross_section_ppi",
 ]
 __doc__ = __doc__.format("\n   ".join(__all__))
 
@@ -36,9 +38,11 @@ import os
 
 import deprecation
 import numpy as np
+import xarray as xr
 from scipy import ndimage, signal
+from scipy.spatial import KDTree
 
-from wradlib import version
+from wradlib import georef, version
 
 
 @deprecation.deprecated(
@@ -300,10 +304,10 @@ def trapezoid(data, x1, x2, x3, x4):
     d[np.logical_and(data >= x2, data <= x3)] = 1
     d[np.logical_and(data > x1, data < x2)] = (
         data[np.logical_and(data > x1, data < x2)] - x1
-    ) / float((x2 - x1))
+    ) / float(x2 - x1)
     d[np.logical_and(data > x3, data < x4)] = (
         x4 - data[np.logical_and(data > x3, data < x4)]
-    ) / float((x4 - x3))
+    ) / float(x4 - x3)
 
     d[np.isnan(data)] = np.nan
 
@@ -590,16 +594,21 @@ def has_geos():
 def get_wradlib_data_path():
     wrl_data_path = os.environ.get("WRADLIB_DATA", None)
     if wrl_data_path is None:
-        raise EnvironmentError("'WRADLIB_DATA' environment variable not set")
+        raise OSError("'WRADLIB_DATA' environment variable not set")
     if not os.path.isdir(wrl_data_path):
-        raise EnvironmentError(f"'WRADLIB_DATA' path '{wrl_data_path}' does not exist")
+        raise OSError(f"'WRADLIB_DATA' path '{wrl_data_path}' does not exist")
     return wrl_data_path
 
 
 def get_wradlib_data_file(relfile):
     data_file = os.path.abspath(os.path.join(get_wradlib_data_path(), relfile))
     if not os.path.exists(data_file):
-        raise EnvironmentError(f"WRADLIB_DATA file '{data_file}' does not exist")
+        try:
+            from wradlib_data import DATASETS
+
+            data_file = DATASETS.fetch(relfile)
+        except ImportError:
+            raise OSError(f"WRADLIB_DATA file '{data_file}' does not exist.")
     return data_file
 
 
@@ -950,7 +959,7 @@ def despeckle(data, n=3, copy=False):
     data0 = _pad_array(data, pad, mode="constant")
     # append n count last dimension
     data0 = _rolling_dim(data0, data.shape[-1])
-    # count NaŃ's and find speckle
+    # count NaN's and find speckle
     nans = np.count_nonzero(np.isnan(data0), axis=-2) == (n - 1)
     # set speckle to NaN
     data[nans] = np.nan
@@ -987,3 +996,299 @@ def has_import(module):
 
 if __name__ == "__main__":
     print("wradlib: Calling module <util> as main...")
+
+
+def vertical_interpolate_volume(vol, elevs=None, method="nearest"):
+    """
+    Vertically interpolate volume data
+
+    Parameters
+    ----------
+    vol : :py:class:`wradlib:wradlib.io.xarray.RadarVolume`
+
+    Keyword Arguments
+    -----------------
+    elevs : iterable of elevations to which interpolate the data. Defaults to None, which does no interpolation and returns a stacked array of the data.
+    method : method for interpolation, defaults to "nearest"
+
+    Returns
+    ----------
+    ds : :py:class:`xarray:xarray.Dataset`
+
+    """
+
+    time = vol[0].time
+    dsx = xr.concat(
+        [
+            v.drop(["time", "rtime"]).assign_coords(
+                {"elevation": v.attrs.get("fixed_angle")}
+            )
+            for v in vol
+        ],
+        dim="elevation",
+    )
+    dsx = dsx.transpose("time", "elevation", "azimuth", "range")
+    if elevs is not None:
+        new_elev = elevs
+        dsx = dsx.interp(elevation=new_elev, method=method)
+    dsx = dsx.assign_coords({"time": time})
+    return dsx
+
+
+def cross_section_ppi(
+    obj,
+    azimuth,
+    method=None,
+    tolerance=None,
+    real_beams=False,
+    bw=1,
+    proj=None,
+    npl=1000,
+):
+    """Cut a cross section from PPI volume scans
+
+        .. versionadded:: 1.18
+
+    This function extracts cross sections from a PPI volume scan along one or more azimuth angles,
+    or along a line connecting two given points.
+    Similar to PyArt's cross_section_ppi function.
+
+    Parameters
+    ----------
+    obj : :py:class:`wradlib:wradlib.io.xarray.RadarVolume` - Radar volume containing PPI sweeps
+        from which azimuthal cross sections will be extracted.
+    azimuths : int, float, slice, tuple or list
+        Value of azimuth to extract the cross section. It can be multiple values
+        in the form of a slice, or a tuple or list of values.
+        Alternatively, it can be given a tuple or list containing coordinates of two
+        arbitrary points in the x,y space of the georeferenced object: [ (x1, y1), (x2,y2) ].
+        In case two points are given, a cross section along the line connecting
+        the points will be generated by selecting the nearest-neighbor values of data.
+        No interpolation of data is performed. If more than two points are given, only
+        the first two are used. The resulting dataset has dimensions xyi (which is just
+        an index along the line connecting the points) and elevation, and
+        coordinates xy (distance along the line from p1) and z. The xy and z coordinates
+        should be used for plotting.
+
+    Keyword Arguments
+    -----------------
+    method : {None, "nearest", "pad", "ffill", "backfill", "bfill"}, optional
+        Method for inexact matches from :py:class:`xarray:xarray.Dataset.sel`.
+    tolerance : {None, "nearest", "pad", "ffill", "backfill", "bfill"}, optional
+        Maximum distance between original and new labels for inexact matches
+        from :py:class:`xarray:xarray.Dataset.sel`.
+    real_beams : bool
+        Option meant for plotting beams with their true beamwidth instead of filling the empty space by
+        stretching the beams (because of how matplotlib pcolormesh works).
+        Defaults to False, which returns a Dataset of cross sections in the specified azimuth(s).
+        If set to True, it will return the same Dataset with additional "fake" beams (extra elevations)
+        so that when plotting with matplotlib pcolormesh the beamwidths are correctly represented
+        according to their width.
+    bw : float, optional
+        beam width in degrees (defaults to 1 degree). This is only used if "real_beams=True".
+    proj : :py:class:`gdal:osgeo.osr.SpatialReference`, :py:class:`cartopy.crs.CRS` or None
+        Projection to use with :py:class:`wradlib.georef.xarray.georeference_dataset`.
+        If GDAL OSR SRS, output is in this projection, else AEQD.
+    npl : int
+        Number of points to make up the line between p1 and p2, in case the user gives two arbitrary points
+        instead of an azimuth value. npl should be high enough to accomodate more points along the line that
+        points of data available (i.e., higher that the resolution of the data). The default value should be
+        enough for most cases, but in case the result looks low resolution try increasing npl.
+
+    Returns
+    ----------
+    obj : :py:class:`xarray:xarray.Dataset` or :py:class:`xarray:xarray.DataArray`
+        Dataset of cross section(s) in the specified azimuth(s) or along the line
+        connecting the given points.
+    """
+
+    if real_beams:
+        # Matplotlib's pcolormesh fills the grid by coloring around each of the gridpoints
+        # up until halfway to the nearest gridpoints.
+        # Then, we need to create fake rays of nan and/or duplicated data so the filling
+        # only extends the shading to cover the beamwidth and no more.
+
+        # Sort array of elevation angles
+        sorted_elevs = np.sort(obj.root.sweep_fixed_angle.data)
+
+        # Calculate midpoints between elevation angles
+        sorted_elevs_midpoints = (sorted_elevs[1:] + sorted_elevs[:-1]) / 2
+
+        # Identify spaces in between beams > bw
+        spaces = sorted_elevs[1:] - sorted_elevs[:-1]
+        separation_needed = spaces > bw
+
+        # Beams separated by exactly 2*bw need only a nan ray at the midpoint
+        two_bw = np.delete(
+            sorted_elevs_midpoints, ~(separation_needed * spaces == (2 * bw))
+        )
+
+        # Beams separated by more than 2*bw need two fake nan rays in between
+        over_two_bw = np.concatenate(
+            (
+                np.delete(
+                    sorted_elevs[:-1] + bw, ~(separation_needed * spaces > (2 * bw))
+                ),
+                np.delete(
+                    sorted_elevs[1:] - bw, ~(separation_needed * spaces > (2 * bw))
+                ),
+            )
+        )
+
+        # Beams separated between bw and 2*bw need a fake nan ray at midpoint and two duplicated data rays over and below
+        condition = separation_needed * (spaces < (2 * bw))
+        under_two_bw_nan = np.delete(sorted_elevs_midpoints, ~condition)
+
+        nan_space = np.delete(spaces - bw, ~condition)
+        under_two_bw_dup_data = np.concatenate(
+            (
+                under_two_bw_nan - nan_space,
+                under_two_bw_nan + nan_space,
+            )
+        )
+
+        # If the first (lowest) real ray falls in this last case, we also need to add an
+        # additional nan ray below:
+        if condition[0]:
+            under_two_bw_nan = np.concatenate(
+                (np.array(sorted_elevs[0] - bw, ndmin=1), under_two_bw_nan)
+            )
+
+        # Join all fake ray elevations for nan or duplicated data
+        nan_fake_elevs = np.sort(
+            np.concatenate((two_bw, over_two_bw, under_two_bw_nan))
+        )
+
+        data_fake_elevs = np.sort(under_two_bw_dup_data)
+
+        # Sort volume in ascending order of elevation
+        obj = sorted(obj, key=lambda ds: ds.attrs["fixed_angle"])
+
+        # Generate fake rays array
+        all_fake_elevs = np.sort(np.concatenate((nan_fake_elevs, data_fake_elevs)))
+        obj_fake = vertical_interpolate_volume(obj, elevs=all_fake_elevs)
+        obj_fake = obj_fake.where(
+            ~obj_fake.elevation.isin(nan_fake_elevs)
+        )  # fill with nan on corresponding elevations
+
+    # Sort volume in ascending order of elevation
+    obj = sorted(obj, key=lambda ds: ds.attrs["fixed_angle"])
+
+    # We do not use this for interpolation here, but for stacking the elevations
+    ds = vertical_interpolate_volume(obj, elevs=None)
+
+    if real_beams:
+        ds = xr.concat([ds, obj_fake], dim="elevation")
+        ds = ds.sortby("elevation")
+
+    # Georeference the data
+    ds = ds.pipe(georef.georeference_dataset, proj=proj)
+
+    try:
+        return ds.sel(azimuth=azimuth, method=method, tolerance=tolerance)
+
+    except (TypeError, ValueError, KeyError):
+        # Is the user providing two points for arbitrary cut?
+        try:
+            p1 = azimuth[0]
+            p2 = azimuth[1]
+            # this is just for checking that the points are valid:
+            x1 = p1[0]
+            y1 = p1[1]
+            x2 = p2[0]
+            y2 = p2[1]
+
+            # if some of the points is outside the radar volume area raise an exception
+            test = np.array(
+                [
+                    ~(ds.x.min() < x1 < ds.x.max()),
+                    ~(ds.x.min() < x2 < ds.x.max()),
+                    ~(ds.y.min() < y1 < ds.y.max()),
+                    ~(ds.y.min() < y2 < ds.y.max()),
+                ]
+            )
+
+            if test.any():
+                raise ValueError(
+                    "At least one of the points given is outside of the radar volume area"
+                )
+
+        except TypeError:
+            # `azimuth` is not a list of azimuths nor a couple of points
+            raise TypeError("Not azimuth values nor points was provided to `azimuth`")
+
+        # Check that the two points given are not the same
+        try:
+            if (p1 == p2).all():
+                raise ValueError(
+                    "p1=p2. The two points given are the same. Please give different points."
+                )
+        except AttributeError:
+            if p1 == p2:
+                raise ValueError(
+                    "p1=p2. The two points given are the same. Please give different points."
+                )
+
+        # number of points to make the line between p1 and p2 (should be greater
+        # than the resolution of the volume)
+        nn = npl
+        # List to collect dataset for every elevation
+        selection = list()
+
+        for el in ds.elevation:
+            # For every elevation, select the array of x and y coordinates
+            x = ds.sel(elevation=el.data.tolist()).x.to_numpy()
+            y = ds.sel(elevation=el.data.tolist()).y.to_numpy()
+
+            # Create a KDTree class to look for the nearest neighbors
+            tree = KDTree(np.c_[x.ravel(), y.ravel()])
+
+            # Create a line of nn points between the selected p1 and p2
+            pline = np.linspace(p1, p2, nn)
+
+            # Search for the nearest neighbors of pline in the x-y array
+            dd, ii = tree.query(pline)
+
+            # Eliminate repeated selections and unravel into original dimensions
+            ii = np.unique(ii)
+
+            # Stack the azimuth and range coordinates and select the points
+            sel = (
+                ds.sel(elevation=(el.data.tolist()))
+                .stack(xyi=("azimuth", "range"))
+                .isel({"xyi": ii})
+            )
+
+            # create values for a new coordinate xy that is the distance to p1 along the line
+            xy = np.sqrt((sel.x - p1[0]) ** 2 + (sel.y - p1[1]) ** 2)
+
+            # Add new coordinates
+            z_coord = sel.z.to_numpy()
+            sel2 = sel.drop_vars({"xyi", "range", "azimuth"}).assign_coords(
+                {"xyi": np.arange(len(xy))}
+            )
+            sel2.coords["xy"] = ("xyi", xy.data)
+            sel2.coords["z"] = ("xyi", z_coord)
+
+            selection.append(sel2.expand_dims("elevation"))
+
+        # Reindex the datasets along the "xyi" dimension
+        selection_reindexed = list()
+        for ll in range(len(selection)):
+            # Since the selection of data for each elevation does not necessarily has the
+            # same amount of xyi points, we reindex the xyi dimension expanding to its
+            # max length to accomodate all data
+            xyi_maxlen = np.array([len(ss.xyi) for ss in selection]).max()
+            selection_reindexed.append(
+                selection[ll].reindex({"xyi": np.arange(xyi_maxlen)})
+            )
+
+        # Combine into a single dataset
+        merged = xr.concat(selection_reindexed, dim="elevation").transpose(
+            "time", "elevation", ...
+        )
+        # We cannot have coordinates with NaN for plotting, so we fill any NaN by propagating values
+        merged["xy"] = merged["xy"].ffill("xyi")
+        merged["z"] = merged["z"].ffill("xyi")
+
+        return merged
